@@ -1,5 +1,5 @@
 box.plot.ade <-
-function(x,  group=NULL,  group2=NULL, data=NULL, vnames=NULL, main=NULL, xlab=NULL, ylab=NULL, ylim=NULL, yticks=NULL, col=NULL, tcol=NULL, bgcol=NULL, lcol=NULL, pdigs=4, alpha=NULL, cex=1, cex.axis=1, lwd=2, h=NULL, lty=2, test=FALSE, varwidth=TRUE, means=FALSE, count=TRUE, zylinder=FALSE, twoside=TRUE, outlier=TRUE, wall=0, type='box'){
+function(x,  group=NULL,  group2=NULL, data=NULL, vnames=NULL, main=NULL, xlab=NULL, ylab=NULL, ylim=NULL, yticks=NULL, col=NULL, tcol=NULL, bgcol=NULL, lcol=NULL, pdigs=4, alpha=NULL, cex=1, cex.axis=1, lwd=2, h=NULL, lty=2, test=FALSE, varwidth=TRUE, means=FALSE, count=TRUE, zylinder=FALSE, twoside=TRUE, paired = FALSE, outlier=TRUE, wall=0, type='box'){
 if(any(par('mfg')!=c(1,1,1,1)) & any(par('mai') < c(1.02, 0.82, 0.82, 0.42))){
 maidiff<-rep(0, 4)
 norm<-c(1.02, 0.82, 0.82, 0.42)
@@ -74,9 +74,9 @@ if(!is.numeric(x))     stop('x is not numeric!!')
 
 
 if(is.null(tcol)  & wall==0)   tcol<-1
-if(is.null(tcol)  & wall!=0)   tcol<-rgb(0.3,0.3,0.45)
+if(is.null(tcol)  & wall!=0)   tcol<-rgb(0.1,0.1,0.25)
 if(is.null(bgcol) & wall==0)   bgcol<-1
-if(is.null(bgcol) & wall!=0)   bgcol<-rgb(0.8, 0.8, 0.9)
+if(is.null(bgcol) & wall!=0)   bgcol<-'#DBE0E8'
 if(is.null(col)  & wall==0)   col<-'gray25'
 if(is.null(col)  & wall!=0)   col<-rgb(0.3,0.3,0.45)
 if(is.null(lcol))  lcol<- tcol
@@ -98,9 +98,16 @@ n.g<- nlevels(g)
 ################################################################################
 p<-NULL
 alt.t<-NULL
+
+test.text<-NULL
+if(!is.logical(test) & is.character(test)){
+test.text<-test
+test<-T
+}
+
 for(k in 1:n.g2){
-if(!is.null(group2)) x.k<- x[g2==levels(g2)[k]]
-if(!is.null(group2)) g.k<- g[g2==levels(g2)[k]]
+if(!is.null(group2)) x.k<- x[which(g2==levels(g2)[k])]
+if(!is.null(group2)) g.k<- g[which(g2==levels(g2)[k])]
 if(is.null(group2))  x.k<- x
 if(is.null(group2))  g.k<- g
 
@@ -135,12 +142,14 @@ if(!is.null(group2)) skewness.k<-abs(as.vector(unlist(by(x, list(g, g2), skewnes
 if(is.null(group2))  skewness.k<-abs(as.vector(unlist(by(x, g,           skewness.ade ,na.rm=TRUE , simplify =FALSE))))
 
 if(all(skewness.k<=1)) {
-p.k<- format_p.ade(t.test(x.k[g.k==levels(g.k)[1]],x.k[g.k==levels(g.k)[2]])$p.value , 4)
-pstri<-'T-Test: '
+p.k<- format_p.ade(t.test(x.k[which(g.k==levels(g.k)[1])],x.k[which(g.k==levels(g.k)[2])], paired = paired)$p.value , 4)
+if(is.null(test.text))  pstri<-'T-Test: '
+if(!is.null(test.text)) pstri<-test.text
 }
 if(any(skewness.k>1)){
-p.k<- format_p.ade(wilcox.test(x.k[g.k==levels(g.k)[1]],x.k[g.k==levels(g.k)[2]])$p.value , 4)
-pstri<-'U-Test: '
+p.k<- format_p.ade(wilcox.test(x.k[which(g.k==levels(g.k)[1])],x.k[which(g.k==levels(g.k)[2])], paired = paired)$p.value , 4)
+if(is.null(test.text))  pstri<-'U-Test: '
+if(!is.null(test.text)) pstri<-test.text
 }
 p<-c(p, p.k)
 }
@@ -232,7 +241,7 @@ bstats<-NULL
 bstats<-as.list(bstats)
 count.n<-NULL
 for(k in 1:n.g2){
-if(!is.null(group2)) bstats[[k]]<-boxplot(x[g2==levels(g2)[k]] ~ g[g2==levels(g2)[k]], plot=FALSE, pch=16, cex=1.25, col=rgb(1,1,1), staplewex=c(0.25,0.25,0.25,0.25), boxwex=c(0.75,0.75,0.75,0.75), ylim=ylim, xlim=xlim, names=NA, varwidth=varwidth)
+if(!is.null(group2)) bstats[[k]]<-boxplot(x[which(g2==levels(g2)[k])] ~ g[which(g2==levels(g2)[k])], plot=FALSE, pch=16, cex=1.25, col=rgb(1,1,1), staplewex=c(0.25,0.25,0.25,0.25), boxwex=c(0.75,0.75,0.75,0.75), ylim=ylim, xlim=xlim, names=NA, varwidth=varwidth)
 if(is.null(group2))  bstats[[k]]<-boxplot(x ~ g, plot=FALSE, pch=16, cex=1.25, col=rgb(1,1,1), staplewex=c(0.25,0.25,0.25,0.25), boxwex=c(0.75,0.75,0.75,0.75), ylim=ylim, xlim=xlim, names=NA, varwidth=varwidth)
 count.n<-c(count.n, bstats[[k]]$n)
 if(varwidth)  xpand<-c(xpand, sqrt(bstats[[k]]$n/sum(!is.na(x)))/2)
@@ -299,7 +308,6 @@ vdensity<-lapply(v, density, na.rm=TRUE, bw='nrd')
 vmin <-lapply(v, min, na.rm=TRUE)
 vmax <-lapply(v, max, na.rm=TRUE)
 
-
 for(k in 1:length(at)){
 yk<-vdensity[[k]]$x
 xk<-(0.4 * vdensity[[k]]$y)/(max(vdensity[[k]]$y, na.rm=TRUE))
@@ -458,13 +466,13 @@ rect(a.glc(2,0),a.glc(1,0+axlin),a.glc(4,0),a.glc(3, 0+nxlin) ,  col=rgb(1,1,1,0
 #Walltype 1
 if(wall==1){
 polygon( par('usr')[c(1,1,2,2)], par('usr')[c(3,4,4,3)], col=bgcol)
-grid(col = rgb(1,1,1), lty = "solid", lwd = 1)
+#grid(col = rgb(1,1,1), lty = "solid", lwd = 1)
 if((n.g*n.g2)>1)                           axis(1, at=xrat,                         labels = vnames, tick=FALSE, col=tcol, lwd.ticks=1, lwd=0, padj=0.5, line =axlin-0.5)
-if(!is.null(yticks) & length(yticks)==1)   axis(2, at=pretty(x, n=yticks),          labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
-if(!is.null(yticks) & length(yticks)>1 )   axis(2, at=yticks,                       labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
-if(is.null(yticks) )                       axis(2,                                  labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
+if(!is.null(yticks) & length(yticks)==1)   zt<-axis(2, at=pretty(x, n=yticks),          labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
+if(!is.null(yticks) & length(yticks)>1 )   zt<-axis(2, at=yticks,                       labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
+if(is.null(yticks) )                       zt<-axis(2,                                  labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
 if(!is.null(group2))                       axis(3, at=((1:n.g2)*(n.g))+0.5-(n.g/2), labels =vnames2, tick=FALSE, col=tcol, lwd.ticks=1, lwd=0, line=-0.75+nxlin)
-
+abline(h=zt, col=rgb(1,1,1), lwd=1)
 abline(v=NULL, h=h, col=rgb(1,1,1), lwd=1, lty=lty)
 abline(v=xrat, col=rgb(1,1,1), lwd=1, lty=1)
 
@@ -527,13 +535,14 @@ box( col=rgb(1,1,1), lwd=2)
 ################################################################################
 #Walltype 2
 if(wall==2){
-grid(col = bgcol, lty = "solid", lwd = 1)
-if((n.g*n.g2)>1)                           axis(1, at=xrat,                         labels = vnames, tick=FALSE,  col=a.coladd.ade(bgcol, -75), lwd.ticks=1, lwd=0, padj=0.5, line =axlin-0.5)
-if(!is.null(yticks) & length(yticks)==1)   axis(2, at=pretty(x, n=yticks),          labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -75), lwd.ticks=1, lwd=0)
-if(!is.null(yticks) & length(yticks)>1 )   axis(2, at=yticks,                       labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -75), lwd.ticks=1, lwd=0)
-if(is.null(yticks) )                       axis(2,                                  labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -75), lwd.ticks=1, lwd=0)
-if(!is.null(group2))                       axis(3, at=((1:n.g2)*(n.g))+0.5-(n.g/2), labels =vnames2, tick=FALSE, col=a.coladd.ade(bgcol, -75), lwd.ticks=1, lwd=0, line=-0.75+nxlin)
 
+if((n.g*n.g2)>1)                           axis(1, at=xrat,                         labels = vnames, tick=FALSE,  col=a.coladd.ade(bgcol, -75), lwd.ticks=1, lwd=0, padj=0.5, line =axlin-0.5)
+if(!is.null(yticks) & length(yticks)==1)   zt<-axis(2, at=pretty(x, n=yticks),          labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -75), lwd.ticks=1, lwd=0)
+if(!is.null(yticks) & length(yticks)>1 )   zt<-axis(2, at=yticks,                       labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -75), lwd.ticks=1, lwd=0)
+if(is.null(yticks) )                       zt<-axis(2,                                  labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -75), lwd.ticks=1, lwd=0)
+if(!is.null(group2))                       axis(3, at=((1:n.g2)*(n.g))+0.5-(n.g/2), labels =vnames2, tick=FALSE, col=a.coladd.ade(bgcol, -75), lwd.ticks=1, lwd=0, line=-0.75+nxlin)
+abline(h=zt, col=bgcol, lwd=1)
+#grid(col = bgcol, lty = "solid", lwd = 1)
 abline(v=NULL, h=h, col=lcol, lwd=1, lty=lty)
 abline(v=xrat, col=bgcol, lwd=1, lty=1)
 
@@ -596,13 +605,13 @@ box(col=a.coladd.ade(bgcol, -75))
 if(wall==3){
 
 polygon( par('usr')[c(1,1,2,2)], par('usr')[c(3,4,4,3)], col=bgcol)
-grid(col = a.coladd.ade(bgcol, -50), lty = "solid", lwd = 1)
+#grid(col = a.coladd.ade(bgcol, -50), lty = "solid", lwd = 1)
 if((n.g*n.g2)>1)                           axis(1, at=xrat,                         labels = vnames, tick=FALSE, col=a.coladd.ade(bgcol, -50), lwd.ticks=1, lwd=0, padj=0.5, line =axlin-0.5)
-if(!is.null(yticks) & length(yticks)==1)   axis(2, at=pretty(x, n=yticks),          labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -50), lwd.ticks=1, lwd=0)
-if(!is.null(yticks) & length(yticks)>1 )   axis(2, at=yticks,                       labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -50), lwd.ticks=1, lwd=0)
-if(is.null(yticks) )                       axis(2,                                  labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -50), lwd.ticks=1, lwd=0)
+if(!is.null(yticks) & length(yticks)==1)   zt<-axis(2, at=pretty(x, n=yticks),          labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -50), lwd.ticks=1, lwd=0)
+if(!is.null(yticks) & length(yticks)>1 )   zt<-axis(2, at=yticks,                       labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -50), lwd.ticks=1, lwd=0)
+if(is.null(yticks) )                       zt<-axis(2,                                  labels =TRUE,       tick=TRUE, col=a.coladd.ade(bgcol, -50), lwd.ticks=1, lwd=0)
 if(!is.null(group2))                       axis(3, at=((1:n.g2)*(n.g))+0.5-(n.g/2), labels =vnames2, tick=FALSE, col=a.coladd.ade(bgcol, -50), lwd.ticks=1, lwd=0, line=-0.75+nxlin)
-
+abline(h=zt, col=a.coladd.ade(bgcol, -50), lwd=1)
 abline(v=NULL, h=h, col=lcol, lwd=1, lty=lty)
 abline(v=xrat, col=a.coladd.ade(bgcol, -50), lwd=1, lty=1)
 
@@ -669,13 +678,13 @@ par(col.main=rgb(1,1,1))
 par(font=2)
 polygon( par('usr')[c(1,1,2,2)], par('usr')[c(3,4,4,3)], col=bgcol)
 
-grid(col = rgb(1,1,1), lty = "solid", lwd = 1)
+#grid(col = rgb(1,1,1), lty = "solid", lwd = 1)
 if((n.g*n.g2)>1)                           axis(1, at=xrat,                         labels = vnames, tick=FALSE, col=tcol, lwd.ticks=1, lwd=0, padj=0.5, line =axlin-0.5)
-if(!is.null(yticks) & length(yticks)==1)   axis(2, at=pretty(x, n=yticks),          labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
-if(!is.null(yticks) & length(yticks)>1 )   axis(2, at=yticks,                       labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
-if(is.null(yticks) )                       axis(2,                                  labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
+if(!is.null(yticks) & length(yticks)==1)   zt<-axis(2, at=pretty(x, n=yticks),          labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
+if(!is.null(yticks) & length(yticks)>1 )   zt<-axis(2, at=yticks,                       labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
+if(is.null(yticks) )                       zt<-axis(2,                                  labels =TRUE,       tick=TRUE, col=tcol, lwd.ticks=1, lwd=0)
 if(!is.null(group2))                       axis(3, at=((1:n.g2)*(n.g))+0.5-(n.g/2), labels =vnames2, tick=FALSE, col=tcol, lwd.ticks=1, lwd=0, line=-0.8+nxlin)
-
+abline(h=zt, col=rgb(1,1,1), lwd=1)
 abline(v=NULL, h=h, col=lcol, lwd=1, lty=lty)
 abline(v=xrat, col=rgb(1,1,1), lwd=1, lty=1)
 
@@ -911,4 +920,3 @@ rect(a.glc(2,0),a.glc(1,0+axlin),a.glc(4,0),a.glc(3, 0+nxlin) ,  col=rgb(1,1,1,0
 ################################################################################
 ################################################################################
 }
-
