@@ -182,9 +182,9 @@ if(is.null(group))  legendon2<- legendon
 #####################################
 # Colors
 if(is.null(tcol)  & wall==0)   tcol<-1
-if(is.null(tcol)  & wall!=0)   tcol<-rgb(0.3,0.3,0.45)
+if(is.null(tcol)  & wall!=0)   tcol<-rgb(0.1,0.1,0.25)
 if(is.null(bgcol) & wall==0)   bgcol<-1
-if(is.null(bgcol) & wall!=0)   bgcol<-rgb(0.8, 0.8, 0.9)
+if(is.null(bgcol) & wall!=0)   bgcol<-'#DBE0E8'
 
 if(is.null(col) & wall!=0 & is.null(group)) col <- rgb(0.3,0.3,0.45)
 if(is.null(col) & wall==0 & is.null(group)) col <- 'gray30'
@@ -755,4 +755,3 @@ if(length(pch)!=nlevels(g)) plot.ade(eval(parse(text=paste("subdat$",x))), eval(
 
 
 }
-
