@@ -24,9 +24,9 @@ vnames  <-vnames1
 #####################################
 # Colors
 if(is.null(tcol)  & wall==0)   tcol<-1
-if(is.null(tcol)  & wall!=0)   tcol<-rgb(0.3,0.3,0.45)
+if(is.null(tcol)  & wall!=0)   tcol<-rgb(0.1,0.1,0.25)
 if(is.null(bgcol) & wall==0)   bgcol<-1
-if(is.null(bgcol) & wall!=0)   bgcol<-rgb(0.8, 0.8, 0.9)
+if(is.null(bgcol) & wall!=0)   bgcol<-'#DBE0E8'
 
 if(is.null(col) & wall!=0 & is.null(vnames)) col <- rgb(0.3,0.3,0.45)
 if(is.null(col) & wall==0 & is.null(vnames)) col <- 'gray30'
@@ -341,4 +341,3 @@ legens.ade(ylim[1], vnames, xlim=xlim, ylim=ylim, lwd=lwd, pch=pch, col=col, leg
 
 
 }
-
